@@ -25,7 +25,7 @@ import sys
 from keystoneclient.auth.identity import v2 as v2_auth
 from keystoneclient.auth.identity import v3 as v3_auth
 from keystoneclient import discover
-from keystoneclient.openstack.common.apiclient import exceptions as ks_exc
+from keystoneclient import exceptions as ks_exc
 from keystoneclient import session
 from oslo_utils import encodeutils
 import six.moves.urllib.parse as urlparse
